==> libreoffice-base-3.2.99.1.tar.bz2: libreoffice-base-3.2.99.1/dbaccess/source/ui/querydesign/TableFieldInfo.cxx <==
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_dbaccess.hxx"

#ifndef DBAUI_TABLEFIELDINFO_HXX
#include "TableFieldInfo.hxx"
#endif
#ifndef _TOOLS_DEBUG_HXX
#include <tools/debug.hxx>
#endif

using namespace dbaui;
//==================================================================
// class OTableFieldInfo
//==================================================================

DBG_NAME(OTableFieldInfo)
OTableFieldInfo::OTableFieldInfo()  :
    m_eDataType(1000)
{
    DBG_CTOR(OTableFieldInfo,NULL);
    m_eFieldType = TAB_NORMAL_FIELD;
}

//------------------------------------------------------------------------------
OTableFieldInfo::~OTableFieldInfo()
{
    DBG_DTOR(OTableFieldInfo,NULL);
}

==> libreoffice-base-3.4.2.3.tar.bz2: libreoffice-base-3.4.2.3/dbaccess/source/ui/querydesign/TableFieldInfo.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_dbaccess.hxx"

#include "TableFieldInfo.hxx"
#include <tools/debug.hxx>

using namespace dbaui;
//==================================================================
// class OTableFieldInfo
//==================================================================

DBG_NAME(OTableFieldInfo)
OTableFieldInfo::OTableFieldInfo()  :
    m_eDataType(1000)
{
    DBG_CTOR(OTableFieldInfo,NULL);
    m_eFieldType = TAB_NORMAL_FIELD;
}

//------------------------------------------------------------------------------
OTableFieldInfo::~OTableFieldInfo()
{
    DBG_DTOR(OTableFieldInfo,NULL);
}




/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
